@@ -14,10 +14,16 @@ COMMANDS = {
 
 def execute_from_command_line(argv=None):
     argv = argv or sys.argv[:]
-    say(f'Hello, Rework CLI, you argv is {argv}', icon='🏂', wrap='C')
+    say(f'Hello, Rework CLI, you argv is {argv}', icon='🏂', wrap='B')
 
     command = argv[1]
 
+    # Hack the `init` command,
+    # append startproject path '.' to argv when command is init
+    if command == 'init':
+        argv.append('.')
+        say(f'Oh hacked, you argv is {argv}', icon='🏂', wrap='A')
+
     if command in COMMANDS:
         COMMANDS.get(command)(argv[2:])
     else:
