@@ -15,10 +15,6 @@ def init(params):
     """Initialize django rework project"""
 
     project = params[0]
-    try:
-        path = params[1]
-    except IndexError:
-        path = None
 
     base_dir = os.getcwd()
     project_dir = base_dir
@@ -50,6 +46,7 @@ def init(params):
     # Others
     copy_template_to_file('.editorconfig', base_dir, **kwargs)
     copy_template_to_file('.gitignore', base_dir, **kwargs)
+    copy_template_to_file('.style.yapf', base_dir, **kwargs)
     copy_template_to_file('requirements.txt', base_dir, **kwargs)
 
     say(f'Initialized completely!', icon='🎨', wrap='C')
